import { createLocalVue, shallowMount } from "@vue/test-utils";
import Vuex from "vuex";
import LayoutBuilder from "../../src/LayoutBuilder.vue";
import state from "../mocks/state";
import Store from "../../src/store/index";

const localVue = createLocalVue();
const store = Store(state);

localVue.use(Vuex);

describe("LayoutBuilder.vue", () => {
  it("renders the PageLayout component", () => {
    const wrapper = shallowMount(LayoutBuilder);
    expect(wrapper.findAll("layoutbuilderpagelayout-stub").length).toBe(1);
  });

  it("renders the PageLayoutForm component", () => {
    const wrapper = shallowMount(LayoutBuilder);
    expect(wrapper.findAll("layoutbuilderpagelayoutform-stub").length).toBe(1);
  });

  describe("triggering contentEdited on the root element", () => {
    it("dispatches editContent with the given data on the store", () => {
      const stub = jest.fn();
      const data = {
        foo: "bar"
      };
      const wrapper = shallowMount(LayoutBuilder, {
        mocks: {
          $store: store
        }
      });

      store.dispatch = stub;

      wrapper.element.dispatchEvent(
        new CustomEvent("contentEdited", {
          detail: data
        })
      );
      expect(stub).toHaveBeenCalledWith("editContent", data);
    });
  });
});
