import cloneDeep from "clone-deep";
import actions from "../../../src/store/actions";
import state from "../../mocks/state";
import Store from "../../../src/store/index";

const store = Store(state);

describe("actions", () => {
  const data = {
    id: "element1"
  };
  const stub = jest.fn();
  store.commit = stub;

  afterEach(() => {
    store.replaceState(cloneDeep(state));
  });

  describe("editContent()", () => {
    describe("when the passed element doesn't exit in the state yet", () => {
      it("commits addElement with the past data to the store", () => {
        actions.editContent(store, data);
        expect(stub).toHaveBeenCalledWith("addElement", data);
      });
    });

    describe("when the passed element exists in the state", () => {
      it("doesn't commit addElement to the store", () => {
        const props = {
          id: "element7"
        };
        actions.editContent(store, props);
        expect(stub).not.toHaveBeenCalledWith("addElement", props);
      });
    });

    it("commits editContent on the store", () => {
      actions.editContent(store, data);
      expect(stub).toHaveBeenCalledWith("editContent", data);
    });

    it("commits setCurrentlyEditableContent on the store with null", () => {
      actions.editContent(store, data);
      expect(stub).toHaveBeenCalledWith("setCurrentlyEditableContent", null);
    });

    it("commits setContentTypesOverlayVisibility on the store with false", () => {
      actions.editContent(store, data);
      expect(stub).toHaveBeenCalledWith(
        "setContentTypesOverlayVisibility",
        false
      );
    });
  });

  describe("showContentTypesOverlay()", () => {
    it("commits setCurrentlyEditableContent on the store with data", () => {
      actions.showContentTypesOverlay(store, data);
      expect(stub).toHaveBeenCalledWith("setCurrentlyEditableContent", data);
    });

    it("commits setContentTypesOverlayVisibility on the store with true", () => {
      actions.showContentTypesOverlay(store, data);
      expect(stub).toHaveBeenCalledWith(
        "setContentTypesOverlayVisibility",
        true
      );
    });
  });

  describe("closeElementsOverlay()", () => {
    it("commits setCurrentlyEditableContent on the store with null", () => {
      actions.closeElementsOverlay(store);
      expect(stub).toHaveBeenCalledWith("setCurrentlyEditableContent", null);
    });

    it("commits setContentTypesOverlayVisibility on the store with false", () => {
      actions.closeElementsOverlay(store);
      expect(stub).toHaveBeenCalledWith(
        "setContentTypesOverlayVisibility",
        false
      );
    });
  });
});
